summaryrefslogtreecommitdiff
path: root/deps/v8/src/objects/module.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/src/objects/module.h')
-rw-r--r--deps/v8/src/objects/module.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/deps/v8/src/objects/module.h b/deps/v8/src/objects/module.h
index 08badf0357..d0ea22e6e5 100644
--- a/deps/v8/src/objects/module.h
+++ b/deps/v8/src/objects/module.h
@@ -112,18 +112,19 @@ class Module : public HeapObject {
ZoneForwardList<Handle<SourceTextModule>>* stack, unsigned* dfs_index,
Zone* zone);
- static V8_WARN_UNUSED_RESULT MaybeHandle<Object> Evaluate(
- Isolate* isolate, Handle<Module> module,
- ZoneForwardList<Handle<SourceTextModule>>* stack, unsigned* dfs_index);
+ static V8_WARN_UNUSED_RESULT MaybeHandle<Object> InnerEvaluate(
+ Isolate* isolate, Handle<Module> module);
// Set module's status back to kUninstantiated and reset other internal state.
// This is used when instantiation fails.
static void Reset(Isolate* isolate, Handle<Module> module);
static void ResetGraph(Isolate* isolate, Handle<Module> module);
// To set status to kErrored, RecordError should be used.
void SetStatus(Status status);
- void RecordError(Isolate* isolate);
+ void RecordErrorUsingPendingException(Isolate* isolate);
+ void RecordError(Isolate* isolate, Handle<Object> error);
#ifdef DEBUG
// For --trace-module-status.
@@ -137,7 +138,8 @@ class Module : public HeapObject {
// JSModuleNamespace object (representing module "bar") is created and bound to
// the declared variable (foo). A module can have at most one namespace object.
class JSModuleNamespace
- : public TorqueGeneratedJSModuleNamespace<JSModuleNamespace, JSObject> {
+ : public TorqueGeneratedJSModuleNamespace<JSModuleNamespace,
+ JSSpecialObject> {
public:
DECL_PRINTER(JSModuleNamespace)
@@ -112,18 +112,19 @@ class Module : public HeapObject {
static void Reset(Isolate* isolate, Handle<Module> module);
static void ResetGraph(Isolate* isolate, Handle<Module> module);
- // To set status to kErrored, RecordError should be used.
+ // To set status to kErrored, RecordError or RecordErrorUsingPendingException
+ // should be used.
void SetStatus(Status status);